@@ -1,12 +1,11 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: apachex.tcl,v 1.2 1999/02/03 21:03:47 jfontain Exp $}
+set rcsId {$Id: apachex.tcl,v 1.3 1999/04/17 09:07:10 jfontain Exp $}
 
-package provide apachex 1.0
+package provide apachex 1.1
 package require apacheutilities
 
-
 namespace eval apachex {
 
     array set data {
@@ -75,10 +74,14 @@ namespace eval apachex {
                 foreach cell [split $line \t] {
                     regsub -all {<[^>]+>} $cell {} cell                                    ;# remove all remaining (formatting) tags
                     if {$column==0} {
-                        set row $cell                                                             ;# use server number as row number
+                        # use server number as row number and ignore generation if present, as in apache version 1.3.6 (cell is n-g
+                        # with n = child server number and g = generation, whereas in apache 1.3.3, only n is present)
+                        scan $cell %u row
                         set current($row) {}                                        ;# keep track of current rows for latter cleanup
+                        set data($row,$column) $row
+                    } else {
+                        set data($row,$column) $cell
                     }
-                    set data($row,$column) $cell
                     incr column
                 }
                 set data($row,5) [::apache::formattedTime $data($row,5)]
