@@ -1,13 +1,13 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: gui.tcl,v 1.16 1999/05/08 20:36:20 jfontain Exp $}
+set rcsId {$Id: gui.tcl,v 1.17 1999/07/14 14:25:45 jfontain Exp $}
 
 proc updateTitle {} {                                                          ;# show modules and poll time or mode in window title
     if {[llength $global::pollTimes]==0} {
-        wm title . "moodss: [commaSeparatedString $modules::(all)] data (asynchronous)"
+        wm title . "moodss: [commaSeparatedString $modules::(names)] data (asynchronous)"
     } else {
-        wm title . "moodss: [commaSeparatedString $modules::(all)] data (every $global::pollTime seconds)"
+        wm title . "moodss: [commaSeparatedString $modules::(names)] data (every $global::pollTime seconds)"
     }
 }
 
@@ -105,7 +105,7 @@ proc createMenuWidget {parentPath readOnly includePollTime} {
     set index(modules) -1
     menuContextHelp::set $help(help) 1 {help on loaded modules}
 
-    foreach module $modules::(all) {
+    foreach module $modules::(indexed) {
         $menu.help.modules add command -label $module... -command "moduleHelpWindow $module"
         menuContextHelp::set $help(modules) [incr index(modules)] "display $module module documentation"
     }
