@@ -4,6 +4,7 @@ exec wish "$0" "$@"
 
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
+proc echo {args} {foreach argument $args {puts -nonewline "$argument "}; puts {}}
 
 proc recordRCSId {variableName empty operation} {
     foreach {header file version} $::rcsId break
@@ -12,7 +13,7 @@ proc recordRCSId {variableName empty operation} {
 }
 trace variable ::rcsId w recordRCSId                                                                ;# keep track of RCS identifiers
 
-set rcsId {$Id: moodss.tcl,v 1.168 1999/06/27 20:23:04 jfontain Exp $}
+set rcsId {$Id: moodss.tcl,v 1.169 1999/07/14 14:28:13 jfontain Exp $}
 
 
 source utility.tcl
@@ -190,7 +191,7 @@ if {[info exists ::geometry]} {
     wm geometry . 400x300
 }
 
-wm iconname . "moodss $modules::(all)"                                                            ;# give the icon a meaningful name
+wm iconname . "moodss $modules::(names)"                                                          ;# give the icon a meaningful name
 image create photo applicationIcon -data [dataGraph::iconData]                                ;# use data graph icon for application
 if {[string compare $tcl_platform(platform) unix]==0} {
     wm iconwindow . [toplevel .icon]
@@ -202,13 +203,18 @@ if {!$readOnly} {
 }
 pack $widget::($scroll,path) -fill both -expand 1
 
-set modules::(synchronous) {}                                                                               ;# look at synchronicity
-foreach module $modules::(all) {
-    if {[lindex [set ${module}::data(pollTimes)] 0]>0} {                                                 ;# if module is synchronous
-        lappend modules::(synchronous) $module
+set modules::(synchronous) {}                                                            ;# save list of synchronous indexed modules
+set names {}
+foreach indexed $modules::(indexed) {
+    if {[lindex [set ${indexed}::data(pollTimes)] 0]>0} {                                                ;# if module is synchronous
+        lappend modules::(synchronous) $indexed
+        set module $modules::($indexed,name)
+        if {[lsearch -exact $names $module]<0} {
+            lappend names $module
+        }
     }
 }
-set modules::(synchronous,string) [commaSeparatedString $modules::(synchronous)]
+set modules::(synchronous,string) [commaSeparatedString $names]                     ;# list on non indexed synchronous modules names
 
 if {[info exists arguments(-p)]} {                                                     ;# command line argument has highest priority
     modules::setPollTimes $arguments(-p)
@@ -286,7 +292,7 @@ proc refresh {} {
 set draggable [expr {!$readOnly}]
 set x 0.0
 set y 0.0
-foreach module $modules::(all) {
+foreach module $modules::(indexed) {
     if {[info exists ${module}::data(views)]} {                                                        ;# user overrode default view
         set viewMembers [set ${module}::data(views)]                                      ;# create and manage a table for each view
     } else {
