@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: record.tcl,v 1.20 1999/03/08 18:18:52 jfontain Exp $}
+set rcsId {$Id: record.tcl,v 1.21 1999/07/14 15:05:10 jfontain Exp $}
 
 
 class record {
@@ -37,7 +37,7 @@ class record {
         puts $file "width [winfo width .] height [winfo height .]"
         puts $file "pollTime $global::pollTime"
         puts $file "modules \{"
-        foreach module $modules::(all) {
+        foreach module $modules::(indexed) {
             puts $file "    $module \{"
             puts $file "        arguments \{$modules::($module,arguments)\}"
             puts $file "        tables \{"
