@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: utility.tcl,v 1.10 1999/03/06 21:27:07 jfontain Exp $}
+set rcsId {$Id: utility.tcl,v 1.11 1999/05/01 19:06:39 jfontain Exp $}
 
 proc minimum {a b} {return [expr {$a<$b?$a:$b}]}
 proc maximum {a b} {return [expr {$a>$b?$a:$b}]}
@@ -47,3 +47,7 @@ proc startGatheringPackageDirectories {} {
         }
     }
 }
+
+proc destroyChildren {path} {
+    eval destroy [winfo children $path]
+}
